@@ -14,7 +14,7 @@ use Mouse::Util::TypeConstraints;
 use namespace::autoclean;
 extends 'App::Sqitch::Command';
 
-our $VERSION = '0.964';
+our $VERSION = '0.965';
 
 has file => (
     is      => 'ro',
@@ -180,7 +180,7 @@ sub get_all {
         message => '',
         exitval => 1,
     } unless @vals;
-    $self->emit( join $/, @vals );
+    $self->emit( join "\n", @vals );
     return $self;
 }
 
@@ -219,7 +219,7 @@ sub get_regex {
             push @out => $key;
         }
     }
-    $self->emit( join $/ => @out );
+    $self->emit( join "\n" => @out );
 
     return $self;
 }
