@@ -17,7 +17,7 @@ use namespace::autoclean;
 
 extends 'App::Sqitch::Command';
 
-our $VERSION = '0.964';
+our $VERSION = '0.965';
 
 sub execute {
     my ( $self, $project ) = @_;
@@ -104,9 +104,9 @@ sub write_plan {
     );
     require App::Sqitch::Plan;
     $fh->print(
-        '%syntax-version=', App::Sqitch::Plan::SYNTAX_VERSION(), $/,
-        '%project=', $project, $/,
-        ( $self->uri ? ('%uri=', $self->uri->canonical, $/) : () ), $/,
+        '%syntax-version=', App::Sqitch::Plan::SYNTAX_VERSION(), "\n",
+        '%project=', "$project\n",
+        ( $self->uri ? ('%uri=', $self->uri->canonical, "\n") : () ), "\n",
     );
     $fh->close or hurl add => __x(
         'Error closing {file}: {error}',
